==> MicrobiomeProfiler_1.2.0.tar.gz: MicrobiomeProfiler/R/enrichHMDB.R <==
#' Metabolism enrichment analysis for microbiome data
#'
#' @param metabo_list a vector of metabolites in HMDB.ID
#' @param pvalueCutoff adjusted pvalue cutoff on enrichment tests to report.
#' @param pAdjustMethod one of "holm", "hochberg", "hommel", "bonferroni",
#' "BH", "BY", "fdr", "none".
#' @param universe universe background genes. If missing, use HMDB db.
#' @param minGSSize minimal size of genes annotated by KEGG term for testing.
#' @param maxGSSize maximal size of genes annotated for testing.
#' @param qvalueCutoff qvalue cutoff on enrichment tests to report.
#' @importFrom clusterProfiler enricher
#' @return A \code{enrichResult} instance.
#' @export
#' @examples
#'
#' x1 <- bitr_smpdb(c("PW_C000164","PW_C000078","PW_C000040"),
#' from_Type = "Metabolite.ID",to_Type = "HMDB.ID")
#' x2 <- enrichHMDB(x1$HMDB.ID)
#'
enrichHMDB <- function(metabo_list,
                        pvalueCutoff      = 0.05,
                        pAdjustMethod     = "BH",
                        universe,
                        minGSSize         = 10,
                        maxGSSize         = 500,
                        qvalueCutoff      = 0.2) {
    res <- enricher(gene = metabo_list,
                    pvalueCutoff  = pvalueCutoff,
                    pAdjustMethod = pAdjustMethod,
                    universe      = universe,
                    minGSSize     = minGSSize,
                    maxGSSize     = maxGSSize,
                    qvalueCutoff  = qvalueCutoff,
                    TERM2GENE = smpdb_data[c("SMPDB.ID","HMDB.ID")],
                    TERM2NAME = smpdb_data[c("SMPDB.ID","Pathway.Name")])
    if (is.null(res))
        return(res)

    slot(res,"ontology") <- "Metabolite"
    slot(res,"organism") <- "microbiome"

    return(res)
}

==> MicrobiomeProfiler_1.11.0.tar.gz: MicrobiomeProfiler/R/enrichHMDB.R <==
#' Metabolism enrichment analysis for microbiome data
#'
#' @param metabo_list a vector of metabolites in HMDB.ID
#' @param pvalueCutoff adjusted pvalue cutoff on enrichment tests to report.
#' @param pAdjustMethod one of "holm", "hochberg", "hommel", "bonferroni",
#' "BH", "BY", "fdr", "none".
#' @param universe universe background genes. If missing, use HMDB db.
#' @param minGSSize minimal size of genes annotated by KEGG term for testing.
#' @param maxGSSize maximal size of genes annotated for testing.
#' @param qvalueCutoff qvalue cutoff on enrichment tests to report.
#' @importFrom clusterProfiler enricher
#' @importFrom methods slot<-
#' @return A \code{enrichResult} instance.
#' @export
#' @examples
#'
#' x1 <- c("HMDB0000001","HMDB0000005","HMDB0000008")
#' x2 <- enrichHMDB(x1)
#'
enrichHMDB <- function(metabo_list,
                        pvalueCutoff      = 0.05,
                        pAdjustMethod     = "BH",
                        universe,
                        minGSSize         = 10,
                        maxGSSize         = 500,
                        qvalueCutoff      = 0.2) {
    res <- enricher(gene = metabo_list,
                    gson = hmdb_gson,
                    pvalueCutoff  = pvalueCutoff,
                    pAdjustMethod = pAdjustMethod,
                    universe      = universe,
                    minGSSize     = minGSSize,
                    maxGSSize     = maxGSSize,
                    qvalueCutoff  = qvalueCutoff)
    if (is.null(res))
        return(res)

    slot(res,"ontology") <- "Metabolite"
    slot(res,"organism") <- "microbiome"

    return(res)
}
